Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
mapsid(1)			 SiLK Tool Suite		       mapsid(1)

NAME
     mapsid - Map between sensor names and sensor numbers

SYNOPSIS
       mapsid [--print-classes] [--print-descriptions]
	     [--site-config-file=FILENAME]
	     [{ <sensor-name> | <sensor-number> } ...]

       mapsid --help

       mapsid --version

DESCRIPTION
     As of SiLK 3.0, mapsid is deprecated, and it will be removed in the SiLK
     4.0 release.  Use rwsiteinfo(1) instead---the "EXAMPLES" section shows how
     to use rwsiteinfo to get output similar to that produced by mapsid.

     mapsid is a utility that maps sensor names to sensor numbers or vice versa
     depending on the input arguments.	Sensors are defined in the silk.conf(5)
     file.

     When no sensor arguments are given to mapsid, the mapping of all sensor
     numbers to names is printed.  When a numeric argument is given, the number
     to name mapping is printed for the specified argument.  When a name is
     given, its numeric id is printed.	For convenience when typing in sensor
     names, case is ignored.

OPTIONS
     Option names may be abbreviated if the abbreviation is unique or is an ex-
     act match for an option.  A parameter to an option may be specified as
     --arg=param or --arg param, though the first form is required for options
     that take optional parameters.

     --print-classes
	 For each sensor, print the classes for which the sensor collects data.
	 The classes are enclosed in square brackets, "[]".

     --print-descriptions
	 For each sensor, print the description of the sensor as defined in the
	 silk.conf file (if any).

     --site-config-file=FILENAME
	 Read the SiLK site configuration from the named file FILENAME.  When
	 this switch is not provided, mapsid searches for the site configuration
	 file in the locations specified in the "FILES" section.

     --help
	 Print the available options and exit.

     --version
	 Print the version number and information about how SiLK was configured,
	 then exit the application.

EXAMPLES
     The following examples demonstrate the use of mapsid.  In addition, each
     example shows how to get similar output using rwsiteinfo(1).

     In the following examples, the dollar sign ("$") represents the shell
     prompt.  The text after the dollar sign represents the command line.  Lines
     have been wrapped for improved readability, and the back slash ("\") is
     used to indicate a wrapped line.

   Name to number mapping
      $ mapsid beta
      BETA ->	  1

      $ rwsiteinfo --fields=sensor,id-sensor --sensors=BETA
      Sensor|Sensor-ID|
	BETA|	     1|

     Unlike mapsid, matching of the sensor name is case-sensitive in rwsiteinfo.

   Number to name mapping
      $ mapsid 3
	  3 -> DELTA

      $ rwsiteinfo --fields=id-sensor,sensor --sensors=3 --delimited=,
      Sensor-ID,Sensor
      3,DELTA

   Print all mappings
      $ mapsid
	  0 -> ALPHA
	  1 -> BETA
	  2 -> GAMMA
	  3 -> DELTA
	  4 -> EPSLN
	  5 -> ZETA
	   ....

      $ rwsiteinfo --fields=id-sensor,sensor --no-titles
	0| ALPHA|
	1|  BETA|
	2| GAMMA|
	3| DELTA|
	4| EPSLN|
	5|  ZETA|
	...

   Print the class
      $ mapsid --print-classes 3 ZETA
	  3 -> DELTA  [all]
      ZETA  ->	   5  [all]

      $ rwsiteinfo --fields=id-sensor,sensor,class:list --sensors=4,ZETA
      Sensor-ID|Sensor|Class:list|
	      3| DELTA|       all|
	      5|  ZETA|       all|

   Print the class and description
      $ mapsid --print-classes --print-description 0 1
	  0 -> ALPHA  [all]  "Primary gateway"
	  1 -> BETA   [all]  "Secondary gateway"

     rwsiteinfo supports using an integer range when specifying sensors.

      $ rwsiteinfo --fields=id-sensor,sensor,class:list,describe-sensor \
	    --sensors=0-1
      Sensor-ID|Sensor|Class:list|Sensor-Description|
	      0| ALPHA|       all|   Primary gateway|
	      1|  BETA|       all| Secondary gateway|

ENVIRONMENT
     SILK_CONFIG_FILE
	 This environment variable is used as the value for the --site-con-
	 fig-file when that switch is not provided.

     SILK_DATA_ROOTDIR
	 This environment variable specifies the root directory of data reposi-
	 tory.	As described in the "FILES" section, mapsid may use this envi-
	 ronment variable when searching for the SiLK site configuration file.

     SILK_PATH
	 This environment variable gives the root of the install tree.	When
	 searching for configuration files, mapsid may use this environment
	 variable.  See the "FILES" section for details.

FILES
     ${SILK_CONFIG_FILE}
     ${SILK_DATA_ROOTDIR}/silk.conf
     /data/silk.conf
     ${SILK_PATH}/share/silk/silk.conf
     ${SILK_PATH}/share/silk.conf
     /usr/local/share/silk/silk.conf
     /usr/local/share/silk.conf
	 Possible locations for the SiLK site configuration file which are
	 checked when the --site-config-file switch is not provided.

SEE ALSO
     rwsiteinfo(1), silk.conf(5), silk(7)

NOTES
     As of SiLK 3.0, mapsid is deprecated; use rwsiteinfo(1) instead.

SiLK 3.22.2			   2026-08-27			       mapsid(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=mapsid&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help